==> sugarcrm-2.5.1b_1.tbz: www/sugarcrm/modules/Leads/ImportVCard.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version
 * 1.1.3 ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * All copies of the Covered Code must include on each user interface screen:
 *    (i) the "Powered by SugarCRM" logo and
 *    (ii) the SugarCRM copyright notice
 * in the same form as they appear in the distribution.  See full license for
 * requirements.
 *
 * The Original Code is: SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) 2004 SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
if(isset($_FILES['vcard']['tmp_name']) && isset($_FILES['vcard']['size']) > 0){
	require_once('include/vCard.php');
	$vcard = new vCard();
	$record = $vcard->importVCard($_FILES['vcard']['tmp_name'],'Lead');
	header("Location: index.php?action=DetailView&module=Leads&record=$record");
    exit();
}else{
require_once('XTemplate/xtpl.php');
echo "\n<p>\n";
echo get_module_title($mod_strings['LBL_MODULE_NAME'], $mod_strings['LBL_MODULE_NAME']." ".$mod_strings['LBL_IMPORT_VCARD'], true); 
echo "\n</p>\n";
global $theme;
$error_msg = '';
$theme_path="themes/".$theme."/";
$image_path=$theme_path."images/";
require_once($theme_path.'layout_utils.php');


global $app_strings;
global $app_list_strings;
global $current_language;
$mod_strings = return_module_language($current_language, 'Leads');

$xtpl=new XTemplate ('modules/Contacts/ImportVCard.html');
$xtpl->assign("MOD", $mod_strings);
$xtpl->assign("APP", $app_strings);
$xtpl->assign("IMAGE_PATH", $image_path);$xtpl->assign("PRINT_URL", "index.php?".$GLOBALS['request_string']);

$xtpl->assign("HEADER", $mod_strings['LBL_IMPORT_VCARD']);

$xtpl->assign("MODULE", $_REQUEST['module']);
if ($error_msg != '')
{
	$xtpl->assign("ERROR", $error_msg);
	$xtpl->parse("main.error");
}


$xtpl->parse("main");

$xtpl->out("main");
 }?>

==> sugarcrm-3.5.1.tbz: www/sugarcrm/modules/Leads/ImportVCard.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version
 * 1.1.3 ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * All copies of the Covered Code must include on each user interface screen:
 *    (i) the "Powered by SugarCRM" logo and
 *    (ii) the SugarCRM copyright notice
 * in the same form as they appear in the distribution.  See full license for
 * requirements.
 *
 * The Original Code is: SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) 2004-2005 SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
if(isset($_FILES['vcard']['tmp_name'])) {
	if (!empty($_FILES['vcard']['tmp_name']) &&  isset($_FILES['vcard']['size']) && $_FILES['vcard']['size'] > 0) {
		require_once('include/vCard.php');
		$vcard = new vCard();
		$record = $vcard->importVCard($_FILES['vcard']['tmp_name'],'Lead');
		header("Location: index.php?action=DetailView&module=Leads&record=$record");
    	exit(); 
	} else {
		header("Location: index.php?action=ImportVCard&module=Leads");
    	exit(); 
	}
}else{
require_once('XTemplate/xtpl.php');
echo "\n<p>\n";
echo get_module_title($mod_strings['LBL_MODULE_NAME'], $mod_strings['LBL_MODULE_NAME']." ".$mod_strings['LBL_IMPORT_VCARD'], true); 
echo "\n</p>\n";
global $theme;
$error_msg = '';
$theme_path="themes/".$theme."/";
$image_path=$theme_path."images/";
require_once($theme_path.'layout_utils.php');


global $app_strings;
global $app_list_strings;
global $current_language;
$mod_strings = return_module_language($current_language, 'Leads');

$xtpl=new XTemplate ('modules/Contacts/ImportVCard.html');
$xtpl->assign("MOD", $mod_strings);
$xtpl->assign("APP", $app_strings);
$xtpl->assign("IMAGE_PATH", $image_path);$xtpl->assign("PRINT_URL", "index.php?".$GLOBALS['request_string']);

$xtpl->assign("HEADER", $mod_strings['LBL_IMPORT_VCARD']);

$xtpl->assign("MODULE", $_REQUEST['module']);
if ($error_msg != '')
{
	$xtpl->assign("ERROR", $error_msg);
	$xtpl->parse("main.error");
}


$xtpl->parse("main");

$xtpl->out("main");
 }?>
